@@ -27,6 +27,7 @@
 #include <QInputDialog>
 #include <QLabel>
 #include <QMenu>
+#include <QPointer>
 #include <QPrintDialog>
 #include <QPrinter>
 #include <QSaveFile>
@@ -46,7 +47,6 @@
 #include <KToolBarPopupAction>
 
 #include <kns3/downloaddialog.h>
-#include <QFileDialog>
 
 #include "interpreter/errormsg.h"
 #include "interpreter/translator.h"
@@ -72,7 +72,7 @@ MainWindow::MainWindow()
 
 	connect(errorDialog, &ErrorDialog::currentlySelectedError, editor, &Editor::markCurrentError);
 
-	colorPicker = 0;
+	colorPicker = nullptr;
 
 	statusBar()->showMessage(i18nc("@info:status the application is ready for commands", "Ready"));
 	updateContentName();  // also sets the window caption to 'untitled'
@@ -107,7 +107,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 void MainWindow::filePrintDialog()
 {
 	QPrinter printer;
-	QPrintDialog *printDialog = new QPrintDialog(&printer, this);
+	QPointer<QPrintDialog> printDialog = new QPrintDialog(&printer, this);
 	if (printDialog->exec()) {
 		QPainter painter;
 		painter.begin(&printer);
@@ -120,7 +120,7 @@ void MainWindow::filePrintDialog()
 void MainWindow::canvasPrintDialog()
 {
 	QPrinter printer;
-	QPrintDialog *printDialog = new QPrintDialog(&printer, this);
+	QPointer<QPrintDialog> printDialog = new QPrintDialog(&printer, this);
 	if (printDialog->exec()) {
 		QPainter painter;
 		painter.begin(&printer);
@@ -137,7 +137,7 @@ void MainWindow::showDirectionDialog()
 }
 void MainWindow::showColorPicker()
 {
-	if (colorPicker == 0) {
+	if (!colorPicker) {
 		colorPicker = new ColorPicker(this);
 		connect(colorPicker, &ColorPicker::pasteText, editor, &Editor::insertPlainText);
 	}
@@ -196,7 +196,7 @@ void MainWindow::setupActions()
 	a->setWhatsThis(i18n("Open File: Open an existing file"));
 
 	//TODO: Is this correct? -- It doesn't seem to be working
-	recentFilesAction = (KRecentFilesAction*)actionCollection()->addAction(KStandardAction::OpenRecent,  "file_recent", editor, SLOT(openFile(const QUrl&)));
+	recentFilesAction = (KRecentFilesAction*)actionCollection()->addAction(KStandardAction::OpenRecent,  "file_recent", editor, SLOT(openFile(QUrl)));
 	recentFilesAction->setStatusTip(i18n("Open a recently used file"));
 	recentFilesAction->setWhatsThis(i18n("Open Recent File: Open a recently used file"));
 	
@@ -380,7 +380,7 @@ void MainWindow::setupActions()
         
 // 	a = new QAction(i18n("Show &Console"), this);
 // 	actionCollection()->addAction("show_console", a);
-// 	a->setStatusTip(i18n("Show or hide the interative Console tab"));
+// 	a->setStatusTip(i18n("Show or hide the interactive Console tab"));
 // 	a->setWhatsThis(i18n("Show Console: Show or hide the interactive Console tab"));
 // 	a->setCheckable(true);
 // 	a->setChecked(false);
@@ -494,7 +494,7 @@ void MainWindow::setupActions()
 
 void MainWindow::setupCanvas()
 {
-	// put the canvas in a layout as the cetral widget of the mainwindow
+	// put the canvas in a layout as the central widget of the mainwindow
 	QWidget* centralWidget = new QWidget(this);
 	QHBoxLayout* centralLayout = new QHBoxLayout(centralWidget);
 	centralLayout->setMargin(0);  // MARGIN_SIZE);
@@ -611,10 +611,10 @@ void MainWindow::toggleGuiFeedback(bool b)
 		disconnect(executer, &Executer::currentlyExecuting, editor, &Editor::markCurrentWord);
 		disconnect(executer, &Executer::currentlyExecuting, inspector, &Inspector::markTreeNode);
 		
-		disconnect(executer, SIGNAL(variableTableUpdated(const QString&, const Value&)),
-			inspector, SLOT(updateVariable(const QString&, const Value&)));
-		disconnect(executer, SIGNAL(functionTableUpdated(const QString&, const QStringList&)),
-			inspector, SLOT(updateFunction(const QString&, const QStringList&)));
+		disconnect(executer, SIGNAL(variableTableUpdated(QString,Value)),
+			inspector, SLOT(updateVariable(QString,Value)));
+		disconnect(executer, SIGNAL(functionTableUpdated(QString,QStringList)),
+			inspector, SLOT(updateFunction(QString,QStringList)));
 		editor->removeMarkings();
 	}
 }
@@ -763,11 +763,11 @@ void MainWindow::updateOnCursorPositionChange()
 
 	Token* cursorToken = editor->currentToken();
 	QString desc;
-	if (cursorToken != 0) {
+	if (cursorToken) {
 		QString look = cursorToken->look();
 		int cat = cursorToken->category();
 		delete cursorToken;
-		cursorToken = 0;
+		cursorToken = nullptr;
 		KLocalizedString layout = ki18n("\"%1\" <%2>");
 		switch (cat) {
 			// not showing the look (only the name):
@@ -868,10 +868,10 @@ QString MainWindow::execute(const QString &operation)
 	Executer* executer = interpreter->getExecuter();
 	disconnect(executer, &Executer::currentlyExecuting, editor, &Editor::markCurrentWord);
 	disconnect(executer, &Executer::currentlyExecuting, inspector, &Inspector::markTreeNode);
-	disconnect(executer, SIGNAL(variableTableUpdated(const QString&, const Value&)),
-		inspector, SLOT(updateVariable(const QString&, const Value&)));
-	disconnect(executer, SIGNAL(functionTableUpdated(const QString&, const QStringList&)),
-		inspector, SLOT(updateFunction(const QString&, const QStringList&)));
+	disconnect(executer, SIGNAL(variableTableUpdated(QString,Value)),
+		inspector, SLOT(updateVariable(QString,Value)));
+	disconnect(executer, SIGNAL(functionTableUpdated(QString,QStringList)),
+		inspector, SLOT(updateFunction(QString,QStringList)));
 
 	if (interpreter->state() == Interpreter::Uninitialized ||
 	    interpreter->state() == Interpreter::Finished ||
@@ -1052,7 +1052,7 @@ void MainWindow::exportToHtml()
 {
 	// copied from edit code for file selection
 	// we do not handle QUrl, so only local files are accepted
-	QString path = QFileDialog::getSaveFileName(this, i18n("Save code as HTML"), QString(), QString("*.html|%1\n*|%2").arg(i18n("HTML documents")).arg(i18n("All files")));
+	QString path = QFileDialog::getSaveFileName(this, i18n("Save code as HTML"), QString(), QString("%1 (*.html);;%2 (*)").arg(i18n("HTML documents")).arg(i18n("All files")));
 	if (path.isEmpty())
 		return;
 	QSaveFile file(path);
@@ -1086,7 +1086,8 @@ void MainWindow::slotMessageDialog(const QString& text)
 
 void MainWindow::getNewExampleDialog()
 {
-	KNS3::DownloadDialog dialog(this);
-	dialog.exec();
+	QPointer<KNS3::DownloadDialog> dialog = new KNS3::DownloadDialog(this);
+	dialog->exec();
 	updateExamplesMenu();
+	delete dialog;
 }
